==> api_guide-1.1.0.tar.gz: lib/src/presentation/widgets/helpers/search_btn.dart <==
/// Copyright © 2023, Oct. Developed by Mouaz M. Al-Shahmeh
/// https://malshahmeh.web.app
/// APIGuide package

/// Import necessary packages
/// Import [flutter/foundation] package files
/// Import [flutter/material] package files
import 'package:flutter/material.dart';

/// Import [provider] package files
import 'package:provider/provider.dart';

/// Import [APIGuide] package files
import '../../../../api_guide.dart';

/// Define [apiGuideSearchBtn] function
Row apiGuideSearchBtn(
  /// BuildContext
  BuildContext context,
) {
  /// ThemeNotifierProvider to check theme attributes' states
  final themeState = context.read<ThemeProvider>();

  return Row(
    mainAxisSize: MainAxisSize.min,
    children: [
      Icon(Constants.searchIcon),
      SizedBox(width: Constants.size8),
      Row(
        children: [
          Text(Constants.searchTxt),

          SizedBox(width: Constants.size8),

          /// Appear only on screens larger than [Constants.smallBreakPoint]
          MediaQuery.of(context).size.width <= Constants.smallBreakPoint
              ? SizedBox()
              : SizedBox(
                  child: DecoratedBox(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(Constants.size5),

                      /// Check the current light/dark theme mode
                      color: themeState.isDarkMode
                          ? ConstantsDarkMode.themeColor(context)
                          : ConstantsLightMode.themeColor(context),
                    ),
                    child: Padding(
                      padding: const EdgeInsets.all(Constants.size5),
                      child: Row(
                        children: [
                          Icon(
                            Constants.cmdKeyIcon,
                            size: Constants.size10,

                            /// Check the current light/dark theme mode
                            color: themeState.isDarkMode
                                ? ConstantsDarkMode.themeColorLight(context)
                                : ConstantsLightMode.themeColorLight(context),
                          ),
                          Text(
                            Constants.plusKTxt,
                            style: TextStyle(
                              /// Check the current light/dark theme mode
                              color: themeState.isDarkMode
                                  ? ConstantsDarkMode.themeColorLight(context)
                                  : ConstantsLightMode.themeColorLight(context),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                )
        ],
      ),
    ],
  );
}

==> api_guide-1.1.7.tar.gz: lib/src/presentation/widgets/helpers/search_btn.dart <==
import 'package:flutter/material.dart';

/// Import [flutter_riverpod] package files
import 'package:flutter_riverpod/flutter_riverpod.dart';

/// Import [APIGuide] package files
import '../../../../api_guide.dart';

/// Define [apiGuideSearchBtn] function
Row apiGuideSearchBtn(
  /// BuildContext
  BuildContext context,

  /// WidgetRef
  WidgetRef ref,
) {
  /// isDarkModeProvider to check theme attributes' states
  final isDarkMode = ref.watch(isDarkModeProvider);

  return Row(
    mainAxisSize: MainAxisSize.min,
    children: [
      Icon(Constants.searchIcon),
      SizedBox(width: Constants.size8),
      Row(
        children: [
          Text(Constants.searchTxt),

          SizedBox(width: Constants.size8),

          /// Appear only on screens larger than [Constants.smallBreakPoint]
          MediaQuery.of(context).size.width <= Constants.smallBreakPoint
              ? SizedBox()
              : SizedBox(
                  child: DecoratedBox(
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(Constants.size5),

                      /// Check the current light/dark theme mode
                      color: isDarkMode
                          ? ConstantsDarkMode.themeColor(ref)
                          : ConstantsLightMode.themeColor(ref),
                    ),
                    child: Padding(
                      padding: const EdgeInsets.all(Constants.size5),
                      child: Row(
                        children: [
                          Icon(
                            Constants.cmdKeyIcon,
                            size: Constants.size10,

                            /// Check the current light/dark theme mode
                            color: isDarkMode
                                ? ConstantsDarkMode.themeColorLight(ref)
                                : ConstantsLightMode.themeColorLight(ref),
                          ),
                          Text(
                            Constants.plusKTxt,
                            style: TextStyle(
                              /// Check the current light/dark theme mode
                              color: isDarkMode
                                  ? ConstantsDarkMode.themeColorLight(ref)
                                  : ConstantsLightMode.themeColorLight(ref),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                )
        ],
      ),
    ],
  );
}
